### Name: train_pred_gau
### Title: Training with Markov chain sampling, predicting for test cases,
###   and evaluating performance with cross-validation
### Aliases: train_pred_gau training_gau predict_gau crossvalid_gau
### Keywords: classif

### ** Examples


##### this is a full demonstration of using this package ######
###############################################################

## parameter setting
n <- 200+400
p <- 400
G <- 6
p_tau_x  <- c(4,1)
p_tau_mu <- c(1.5,0.01)
p_tau_nu <- c(1.5,0.01)
tau_mu <- 100 

## generate a data set
data <- gen_bayesgau (n,p,G,tau_nu=100,tau_mu,p_tau_x )

## specifying cases as training set
ix_tr <- 1:200 

## ordering features by F-statistic
i_sel <- order_features(data$X[ix_tr,],data$y[ix_tr])
vars <- i_sel$vars[1:10]
cutoff <- i_sel$fstat[10]

## training model with bias-corrected method
out_tr_cor <- training_gau(
    G = G, data$X[ix_tr,vars,drop=FALSE], data$y[ix_tr], 
    prior_y = rep(1,G),
    p_tau_nu, p_tau_mu, p_tau_x ,
    nos_super = 400, nos_trans = 1, ini_taus=rep(1,3),
    ## information on correcting for bias 
    cor=1, p=p,cutoff=cutoff, min_qf=exp(-10),nos_lambda=100, 
    stepsize_log_tau=0.5, no_steps=5 
    )

## make prediction
out_pred_cor <- predict_gau( 
    data$X[-(ix_tr),vars,drop=FALSE], out_tr_cor, 
    pred_range=c(50,400), thin = 1) 

## define 0-1 loss function
Mlosser <- matrix (1,G,G)
diag(Mlosser) <- 0

## randomly generate a loss function
Mloss <- matrix(1,G,G)
Mloss <- matrix(exp(rnorm(G^2,0,2)),G,G)
diag(Mloss) <- 0

## evaluate prediction with test cases 

## calculating average minus log probabilities
amlp_cor <- comp_amlp(out_pred_cor,data$y[-ix_tr])

## calculating error rate
er_cor <- comp_loss(out_pred_cor,data$y[-ix_tr],Mlosser)

## calculating average loss from the randomly generated loss function
l_cor <- comp_loss(out_pred_cor,data$y[-ix_tr],Mloss)




